@@ -25,7 +25,7 @@ help(void)
 	printf(MODULENAME" v%s options:\n"
 	       "  --%s address[/mask]\n"
 	       "				Network address to map to.\n\n",
-	       NETFILTER_VERSION, opts[0].name);
+	       IPTABLES_VERSION, opts[0].name);
 }
 
 static u_int32_t
@@ -74,7 +74,7 @@ parse_to(char *arg, struct ip_nat_range *range)
 	char *slash;
 	struct in_addr *ip;
 	u_int32_t netmask;
-	int bits;
+	unsigned int bits;
 
 	range->flags |= IP_NAT_RANGE_MAP_IPS;
 	slash = strchr(arg, '/');
@@ -95,7 +95,7 @@ parse_to(char *arg, struct ip_nat_range *range)
 			netmask = ip->s_addr;
 		}
 		else {
-			if ((bits = string_to_number(slash+1, 0, 32)) == -1)
+			if (string_to_number(slash+1, 0, 32, &bits) == -1)
 				exit_error(PARAMETER_PROBLEM, "Bad netmask `%s'\n",
 					   slash+1);
 			netmask = bits2netmask(bits);
@@ -128,7 +128,7 @@ parse(int c, char **argv, int invert, unsigned int *flags,
 
 	switch (c) {
 	case '1':
-		if (check_inverse(optarg, &invert))
+		if (check_inverse(optarg, &invert, NULL, 0))
 			exit_error(PARAMETER_PROBLEM,
 				   "Unexpected `!' after --%s", opts[0].name);
 
@@ -179,10 +179,11 @@ save(const struct ipt_ip *ip, const struct ipt_entry_target *target)
 	print(ip, target, 0);
 }
 
+static
 struct iptables_target target_module
 = { NULL,
     MODULENAME,
-    NETFILTER_VERSION,
+    IPTABLES_VERSION,
     IPT_ALIGN(sizeof(struct ip_nat_multi_range)),
     IPT_ALIGN(sizeof(struct ip_nat_multi_range)),
     &help,
