@@ -4,7 +4,7 @@
  *
  * This code is distributed under the terms of GNU GPL v2
  *
- * $Id: iptables-restore.c,v 1.22 2002/08/07 09:07:41 laforge Exp $
+ * $Id: iptables-restore.c,v 1.25 2003/03/06 11:56:31 laforge Exp $
  */
 
 #include <getopt.h>
@@ -101,14 +101,15 @@ int main(int argc, char *argv[])
 {
 	iptc_handle_t handle;
 	char buffer[10240];
-	unsigned int line = 0;
 	int c;
 	char curtable[IPT_TABLE_MAXNAMELEN + 1];
 	FILE *in;
 	const char *modprobe = 0;
+	int in_table = 0;
 
 	program_name = "iptables-restore";
 	program_version = IPTABLES_VERSION;
+	line = 0;
 
 #ifdef NO_SHARED_LIBS
 	init_extensions();
@@ -154,17 +155,18 @@ int main(int argc, char *argv[])
 	
 	/* Grab standard input. */
 	while (fgets(buffer, sizeof(buffer), in)) {
-		int ret;
+		int ret = 0;
 
 		line++;
 		if (buffer[0] == '\n') continue;
 		else if (buffer[0] == '#') {
 			if (verbose) fputs(buffer, stdout);
 			continue;
-		} else if (strcmp(buffer, "COMMIT\n") == 0) {
+		} else if ((strcmp(buffer, "COMMIT\n") == 0) && (in_table)) {
 			DEBUGP("Calling commit\n");
 			ret = iptc_commit(&handle);
-		} else if (buffer[0] == '*') {
+			in_table = 0;
+		} else if ((buffer[0] == '*') && (!in_table)) {
 			/* New table */
 			char *table;
 
@@ -192,8 +194,9 @@ int main(int argc, char *argv[])
 			}
 
 			ret = 1;
+			in_table = 1;
 
-		} else if (buffer[0] == ':') {
+		} else if ((buffer[0] == ':') && (in_table)) {
 			/* New chain. */
 			char *policy, *chain;
 
@@ -252,7 +255,7 @@ int main(int argc, char *argv[])
 
 			ret = 1;
 
-		} else {
+		} else if (in_table) {
 			int a;
 			char *ptr = buffer;
 			char *pcnt = NULL;
